@@ -9,9 +9,14 @@ viewing tool, like DS9
 # ----------------------------------------------------------------------------
 from ._astropy_init import *
 # ----------------------------------------------------------------------------
+from pkg_resources import get_distribution, DistributionNotFound
+
+__all__ = ['__version__', '__githash__']
+
+
 
 try:
-    from .xpa_wrap import XPA
+    from . import imexamxpa
     _have_xpa = True
 except ImportError:
     _have_xpa = False
@@ -31,11 +36,11 @@ if not _ASTROPY_SETUP_:
     except ImportError:
         raise ImportError("astropy required but not found")
 
-    try:
-        from .version import version as __version__
-    except ImportError:
-        __version__ = ''
-    try:
-        from .version import githash as __githash__
-    except ImportError:
-        __githash__ = ''
+
+try:
+    release = get_distribution('imexam').version
+    __version__ = '.'.join(release.split('.')[:4])
+except DistributionNotFound:
+    # package is not installed
+    __version__ = 'unknown'
+    __githash__ = ''
