@@ -4,8 +4,6 @@
 the viewer and the imexamine classes
 """
 
-from __future__ import print_function, division, absolute_import
-
 import warnings
 import logging
 import os
@@ -20,7 +18,7 @@ except ImportError:
     have_ginga = False
 
 try:
-    import xpa
+    from . import imexamxpa
     have_xpa = True
     from .ds9_viewer import ds9
 except ImportError:
@@ -31,7 +29,7 @@ from .imexamine import Imexamine
 __all__ = ["Connect"]
 
 
-class Connect(object):
+class Connect:
     """Connect to a display device to look at and examine images.
 
     The control features below are a basic set that should be available
@@ -214,8 +212,7 @@ class Connect(object):
         print("\nPress 'q' to quit\n")
         keys = self.exam.get_options()  # possible commands
         self.exam.print_options()
-        cstring = "Current image {0}".format(self.get_filename(),)
-        print(cstring)
+        print(f"Current image {self.get_filename()}")
 
         # set defaults
         self._current_frame = self.frame()
@@ -267,9 +264,7 @@ class Connect(object):
                                 self.exam.do_option(
                                     x, y, current_key)
                 except KeyError:
-                    print(
-                        "Invalid key, use\n: {0}".format(
-                            self.exam.print_options()))
+                    print(f"Invalid key, use\n: {self.exam.print_options()}")
                     self.exam._close_plots()
 
     def _check_frame(self):
@@ -284,12 +279,10 @@ class Connect(object):
             self.exam.set_data(self.window.get_data())
             self._current_frame = frame
             try:
-                cstring = "\nCurrent image {0:s}".format(
-                        self.get_frame_info()['filename'],)
+                cstring = f"\nCurrent image {self.get_frame_info()['filename']}"
             except TypeError:
                 cstring = "\nuser array in frame"
             self.log.info(cstring)
-            print(cstring)
 
     def _check_slice(self):
         """check if the user switched slice images."""
@@ -297,10 +290,8 @@ class Connect(object):
         if self._current_slice != this_slice:
             self.exam.set_data(self.window.get_data())
             self._current_slice = this_slice
-            cstring = "\nCurrent slice {0:s}".format(
-                self.get_frame_info()['naxis'],)
+            cstring = f"\nCurrent slice {self.get_frame_info()['naxis']}"
             self.log.info(cstring)
-            print(cstring)
 
     #  Implement the following functions in your viewer class
 
@@ -520,10 +511,10 @@ class Connect(object):
             print("You need to specify the key-name for the function")
             return None
         if key in self.exam._reserved_keys:
-            print("{0:s} is reserved".format(key))
+            print(f"{key} is reserved")
             return None
         if key not in self.exam.imexam_option_funcs:
-                print("Key not available")
+                print(f"{key} not available")
                 return None
         fname = self.exam.imexam_option_funcs[key][0].__name__
         parname = fname + "_pars"
@@ -560,11 +551,11 @@ class Connect(object):
             print("No information for parameters available")
             return
         if item not in current_dict:
-            print("No parameter of that name in dictionary")
+            print(f"No parameter {item} of that name in dictionary")
             return
         else:
             current_dict[item][0] = value
-            print("set {0}: {1} to {2}".format(parname, item, value))
+            print(f"set {parname}: {item} to {value}")
             return
 
     def aimexam(self, get_name=False):
@@ -589,6 +580,17 @@ class Connect(object):
         else:
             return(self.exam.colplot_pars)
 
+    def dimexam(self, get_name=False):
+        """Show the current parameters for the 'd' key.
+
+        Either returns the name of the function associated with the keyname
+        Or it returns the dictionary of plotting parameters for that key
+        """
+        if get_name:
+            return self.exam.imexam_option_funcs['d'][0].__name__
+        else:
+            return(self.exam.com_center_pars)
+
     def eimexam(self, get_name=False):
         """Show the current parameters for the 'e' key, returns dict."""
         if get_name:
@@ -705,7 +707,6 @@ class Connect(object):
             self.exam.get_plot_name()  # show the current default
         else:
             if os.access(filename, os.F_OK):
-                warnings.warn(
-                    "File with that name already exists:{0s}".format(filename))
+                warnings.warn(f"File with that name already exists:{filename}")
             else:
                 self.exam.set_plot_name(filename)
