@@ -23,10 +23,9 @@ http://hea-www.harvard.edu/saord/xpa/
 
 """
 
-from __future__ import print_function, division, absolute_import
-
 import os
 import shutil
+import sys
 import numpy as np
 from subprocess import Popen
 import time
@@ -41,7 +40,7 @@ from subprocess import call
 
 # The XPA class controls interaction with DS9
 from .xpa_wrap import XPA
-from xpa import XpaException
+from .imexamxpa import XpaException
 
 from . import util
 from astropy.io import fits
@@ -57,7 +56,7 @@ class UnsupportedImageShapeException(Exception):
 __all__ = ['ds9']
 
 
-class ds9(object):
+class ds9:
     """Control all interactions between the user and the DS9 window.
 
     The ds9() contructor takes a ds9 target as its main argument.
@@ -203,6 +202,9 @@ class ds9(object):
         self._ds9_process = None
         self._ds9_path = None
 
+        # see if the package logger was already started
+        self.log = logging.getLogger(__name__)
+
         # An existing ds9 was suggested. Confirm existence
         # and attach.
         if target:
@@ -217,8 +219,7 @@ class ds9(object):
                     if target in window:
                         self._xpa_name = target
             if not self._xpa_name:
-                print("\nDS9 target: {0:s} doesn't exist.\n{1}".format(target,
-                                                                       list(active)))
+                print(f"\nDS9 target: {target} doesn't exist.\n{list(active)}")
                 raise ValueError(
                     "Please choose an existing target."
                 )
@@ -227,7 +228,7 @@ class ds9(object):
             if not path:
                 self._ds9_path = util.find_path('ds9')
                 if not self._ds9_path:
-                    raise OSError("Could not find ds9 executable on your path")
+                    raise OSError("Could not find ds9 executable on your path or alias")
 
             else:
                 self._ds9_path = path
@@ -473,7 +474,7 @@ class ds9(object):
     def _stop_process(self):
         """stop the ds9 window process nicely.
 
-        only if this package started it
+        but only if this package started it
         """
         try:
             if self._ds9_process:
@@ -484,7 +485,7 @@ class ds9(object):
                         self._process_list.remove(self._ds9_process)
 
         except XpaException as e:
-            print("XPA Exception: {0}".format(e))
+            print(f"XPA Exception: {repr(e)}")
 
     def _purge_local(self):
         """remove temporary directories from the unix socket."""
@@ -544,7 +545,7 @@ class ds9(object):
 
         except Exception as e:  # refine error class
             warnings.warn("Opening ds9 failed")
-            print("Exception: {}".format(repr(e)))
+            print(f"Exception: {repr(e)}")
             from signal import SIGTERM
             try:
                 pidtokill = p.pid
@@ -584,7 +585,8 @@ class ds9(object):
         # this is the first directory the servers looks for on the path
         env["XPA_TMPDIR"] = self._tmpd_name
 
-        iraf_unix = "{0:s}/.IMT".format(self._tmpd_name)
+        unix_name = "{0:s}/.IMT".format(self._tmpd_name)
+
         # that should be unique enough, something better?
         title = str(time.time())
         try:
@@ -592,7 +594,7 @@ class ds9(object):
             p = Popen([self._ds9_path,
                        "-xpa", "local",
                        "-unix_only", "-title", title,
-                       "-unix", "{0:s}".format(iraf_unix)],
+                       "-unix", "{0:s}".format(unix_name)],
                       shell=False, env=env)
 
             # wait until ds9 starts and the .IMT socket exists
@@ -606,10 +608,9 @@ class ds9(object):
             if wait_time == 0:
                 from signal import SIGTERM
                 os.kill(p.pid, SIGTERM)
-                print(
-                    "Connection timeout with the ds9. Try to increase the \
+                print(f"Connection timeout with the ds9. Try to increase the \
                     *wait_time* parameter (current value \
-                    is  {0:d} s)".format(self.wait_time,))
+                    is  {self.wait_time} s)")
 
         except (OSError, ValueError, AttributeError) as e:
             warnings.warn("Starting ds9 failed")
@@ -634,19 +635,7 @@ class ds9(object):
         env["XPA_TMPDIR"] = "/tmp/xpa"  # for all local connections
         self._need_to_purge = True
         self._xpa_method = 'local'
-        return xpaname, iraf_unix
-
-    def set_iraf_display(self):
-        """Set the environemnt variable IMTDEV to the current display.
-
-        the socket address of the current imexam.ds9 instance is used
-        Notes
-        -----
-        For example, your pyraf commands will use this ds9 for display.
-
-        TODO: Not sure this is still needed. Stop using IRAF.
-        """
-        os.environ["IMTDEV"] = "unix:{0:s}".format(self._ds9_unix_name)
+        return xpaname, unix_name
 
     def _check_ds9_process(self):
         """Check to see if the ds9 process is still running.
@@ -659,7 +648,7 @@ class ds9(object):
         """
         if self._ds9_process:
             ret = self._ds9_process.poll()
-            if ret is not None:
+            if ret:
                 raise RuntimeError("The ds9 process is externally killed.")
                 self._purge_local()
 
@@ -704,7 +693,7 @@ class ds9(object):
         try:
             xpa_string = self.get("imexam any coordinate image")
         except XpaException as e:
-            print("Xpa problem reading cursor: {0}".format(repr(e)))
+            print(f"Xpa problem reading cursor: {repr(e)}")
             raise KeyError
         except ValueError:
             raise ValueError("Outside of data range")
@@ -1085,7 +1074,7 @@ class ds9(object):
                 try:
                     header = self.get("fits header")
                 except XpaException as e:
-                    print("XPA Exception getting header: {0}".format(e))
+                    print(f"XPA Exception getting header: {repr(e)}")
                     return None
 
             return header
@@ -1253,17 +1242,17 @@ class ds9(object):
         if not filename:
             print("No filename specified")
         else:
-            self.set("file mecube new {0:s}".format(filename))
+            self.set(f"file mecube new {filename}")
 
     def load_mef_as_multi(self, filename=None):
         """Load a Mult-Extension-Fits image into multiple frames."""
         if not filename:
             print("No filename specified")
         else:
-            self.set("file multiframe {0:s}".format(filename))
+            self.set(f"file multiframe {filename}")
 
-    def mark_region_from_array(
-            self, input_points, ptype="image", textoff=10, size=4):
+    def mark_region_from_array(self, input_points,
+                               ptype="image", textoff=10, size=4):
         """mark ds9 regions regions  given an input list of tuples.
 
          a convienence function, you can also use set_region
@@ -1302,7 +1291,7 @@ class ds9(object):
             if rtype == "circle":
                 pline = rtype + " " + \
                     str(location[x]) + " " + str(location[y]) + " " + str(size)
-                print(pline)
+                self.log.info(pline)
                 self.set_region(pline)
 
             try:
@@ -1310,7 +1299,7 @@ class ds9(object):
                     pline = "text " + str(float(location[x]) + textoff) +\
                             " " + str(float(location[y]) + textoff) + " '" +\
                             str(location[comment]) + "' #font=times"
-                    print(pline)
+                    self.log.info(pline)
                     self.set_region(pline)
             except IndexError:
                 pass
@@ -1349,8 +1338,8 @@ class ds9(object):
             f.close()
 
         except IOError as e:
-            warnings.warn("Unable to open input file")
-            print("{0}".format(e))
+            warnings.warn(f"Unable to open input file")
+            print("{repr(e)}")
             raise ValueError
 
         # assumed defaults for simple regions file
@@ -1383,7 +1372,7 @@ class ds9(object):
                 f.write(pline)
         f.close()
 
-        print("output reg file saved to: {0:s}".format(out))
+        self.log.info(f"output reg file saved to: {out}")
 
     def match(self, coordsys="wcs", frame=True, crop=False, fslice=False,
               scale=False, bin=False, colorbar=False, smooth=False,
@@ -1519,8 +1508,7 @@ class ds9(object):
             cstring = "rotate {0:s}".format(str(value))
             self.set(cstring)
         cstring = "Image rotated at {0:s}".format(self.get("rotate"))
-        print(cstring)
-        logging.info(cstring)
+        self.log.info(cstring)
 
     def save_regions(self, filename=None):
         """save the regions in the current window to a DS9 style regions file.
@@ -1595,14 +1583,14 @@ class ds9(object):
 
           """
         mode_scale = ["zscale", "zmax", "minmax"]
-        cstring = "scale {0:s}".format(scale)
+        cstring = f"scale {scale}"
 
         if scale in mode_scale:
-            cstring = "scale mode {0:s}".format(scale)
+            cstring = f"scale mode {scale}"
         try:
             self.set(cstring)
         except (XpaException, ValueError):
-            print("{0:s} not valid".format(cstring))
+            print(f"{cstring} not valid")
             print(_help)
 
     def set_region(self, region_string=""):
@@ -1620,7 +1608,7 @@ class ds9(object):
         set_region("line 0 400 3 400 #color=red")
 
         """
-        command = "regions command {{ {0:s} }}\n".format(region_string)
+        command = f"regions command {{ {region_string} }}\n"
         self.set(command)
 
     def showme(self):
@@ -1646,8 +1634,8 @@ class ds9(object):
         """Create a snap shot of the current window, save in specified format.
 
         This function bypasses the XPA  calling routines to avoid a bug with
-        the X11/XPA interface. Instead is uses the os import function which
-        takes a snapshot of the specified x11 window.
+        the X11/XPA interface. Instead is uses the os function which
+        takes a snapshot of the specified window.
 
         Parameters
         ----------
@@ -1675,36 +1663,33 @@ class ds9(object):
         else:
             filename += "_snap." + format
 
-        cstring = ['import']
-        cstring.append('-window ')
-        # get the name of the window
-        if "local" in self._xpa_method:
-            win_name = self._xpa_name.split("DS9_")[1].split(".")
-            newname = "SAOImage "
-            newname += (".".join(win_name[0:2]))
-            cstring.append(newname)
-        else:
+        # screencapture works with OSX
+        if sys.platform == "darwin":
+            print("Not implemented for darwin platform")
+            return None
+        else:  # import only works with x11 windows
+            cstring = ['import']
+            cstring.append('-window ')
             cstring.append(self._xpa_name)
+            if "jpeg" in filename:
+                cstring.append(' -quality')
+                cstring.append(str(resolution))
 
-        if "jpeg" in filename:
-            cstring.append(' -quality')
-            cstring.append(str(resolution))
+            cstring.append(filename)
 
-        cstring.append(filename)
-
-        # self.set(cstring)
-        # save the local directory, erase later?
-        call(cstring)
-        print("Image saved to {0:s}".format(filename))
-        logging.info("Image saved to {0:s}".format(filename))
-        return(filename)
+            # self.set(cstring)
+            # save the local directory, erase later?
+            call(cstring)
+            print(f"Image saved to {filename}")
+            self.log.info(f"Image saved to {filename}")
+            return(filename)
 
     def grab(self):
         """Make a copy of the image view."""
-        backend = get_backend().lower()
-        fname = self.snapsave(format="png")
-        if "nbagg" in backend:  # save inside the notebook
-                data = mpimage.imread(fname)
+        valid_fname = self.snapsave(format="png")
+        if valid_fname:
+            if "nbagg" in get_backend().lower():  # save inside the notebook
+                data = mpimage.imread(valid_fname)
                 plt.clf()
                 return plt.imshow(data, origin="upper")
 
