@@ -4,10 +4,8 @@
    For default key and mouse shortcuts in a Ginga window, see:
    https://ginga.readthedocs.org/en/latest/quickref.html
 """
-from __future__ import print_function, division, absolute_import
 
 import sys
-import os
 import traceback
 import warnings
 import threading
@@ -16,16 +14,18 @@ import numpy as np
 from . import util
 from astropy.io import fits
 
-from ginga.misc import log, Settings
-from ginga.AstroImage import AstroImage
-from ginga.BaseImage import BaseImage
-from ginga import cmap
-from ginga.util import paths
-from ginga.util import wcsmod
+try:
+    from ginga.misc import log, Settings
+    from ginga.AstroImage import AstroImage
+    from ginga.BaseImage import BaseImage
+    from ginga import cmap
+    from ginga.util import paths
+    from ginga.util import wcsmod
+    wcsmod.use('AstropyWCS')
+except ImportError:
+    print("Ginga not installed, use other viewer, or no viewer")
 
 
-wcsmod.use('AstropyWCS')
-
 # module variables
 _matplotlib_cmaps_added = False
 
@@ -35,7 +35,7 @@ _matplotlib_cmaps_added = False
 __all__ = ['ginga', 'ginga_general']
 
 
-class ginga_general(object):
+class ginga_general:
 
     """ A base class which controls all interactions between the user and the
     ginga widget.
@@ -131,9 +131,7 @@ class ginga_general(object):
                 cmap.add_matplotlib_cmaps()
                 _matplotlib_cmaps_added = True
             except Exception as e:
-                print(
-                    "Failed to load matplotlib colormaps: {0}".format(
-                        repr(e)))
+                print(f"Failed to load matplotlib colormaps: {repr(e)}")
 
         # bindings preferences shared with other ginga viewers
         bind_prefs = self.prefs.createCategory('bindings')
@@ -192,7 +190,7 @@ class ginga_general(object):
         self._capturing = False
         top_canvas = self.ginga_view.get_canvas()
         top_canvas.delete_object_by_tag("imexam-canvas")
-        self.logger.debug("canvas deleted top=%s" % top_canvas.objects)
+        self.logger.debug(f"canvas deleted top={top_canvas.objects}")
 
     def __str__(self):
         """Return viewer name."""
@@ -333,7 +331,7 @@ class ginga_general(object):
                 # did we get a key event?
                 if len(self._keyvals) > 0:
                     (k, x, y) = self._keyvals
-                    print("key pressed:{0:s} on x:{1} y:{2}".format(k, x, y))
+                    print(f"key pressed:{k} on x:{x} y:{y}")
                     break
 
         # ginga is returning 0 based indexes
@@ -502,10 +500,8 @@ class ginga_general(object):
         data_x, data_y = self.ginga_view.get_last_data_xy()
 
         if "q" not in keyname:
-            print("read: {0:s} at {1}, {2}".format(keyname, data_x, data_y))
-
-        self.logger.debug("key %s pressed at data %f,%f" % (
-            keyname, data_x, data_y))
+            print(f"read: {keyname} at {data_x}, {data_y}")
+        self.logger.debug(f"key {keyname} pressed at data {data_x},{data_y}")
 
         if keyname == 'q':
             # temporarily switch to non-imexam mode
@@ -531,14 +527,11 @@ class ginga_general(object):
         # this will be picked up by the caller in readcursor()
         self._keyvals = (keyname, data_x, data_y)
         with self._rlock:
-            self.logger.debug(
-                "x,y,data dim: %f %f %i" %
-                (data_x, data_y, data.ndim))
-            self.logger.debug("exam=%s" % str(self.exam))
+            self.logger.debug(f"x,y,data dim: {data_x} {data_y} {data.ndim}")
+            self.logger.debug(f"exam={self.exam}")
 
             # call the imexam function directly
-            self.logger.debug(
-                "calling examine function key={0}".format(keyname))
+            self.logger.debug(f"calling examine function key={keyname}")
             try:
                 method = self.exam.imexam_option_funcs[keyname][0]
             except KeyError:
@@ -546,12 +539,12 @@ class ginga_general(object):
             try:
                 method(data_x, data_y, data)
             except Exception as e:
-                self.logger.error("Failed examine function: %s" % (repr(e)))
+                self.logger.error(f"Failed examine function: {repr(e)}")
                 try:
                     # log traceback, if possible
                     (type, value, tb) = sys.exc_info()
                     tb_str = "".join(traceback.format_tb(tb))
-                    self.logger.error("Traceback:\n%s" % (tb_str))
+                    self.logger.error(f"Traceback:\n {tb_str}")
                 except Exception:
                     tb_str = "Traceback information unavailable."
                     self.logger.error(tb_str)
@@ -584,6 +577,8 @@ class ginga_general(object):
         if fname is None:
             raise ValueError("No filename or HDU provided")
 
+        image = AstroImage(logger=self.logger)
+
         if isinstance(fname, (fits.hdu.image.PrimaryHDU, fits.hdu.image.ImageHDU)):
             # Simple fits, data + header
             shortname = fname
@@ -592,11 +587,21 @@ class ginga_general(object):
                 extv = None
                 extver = 0
 
+            if extver:
+                hdu = shortname[extver]
+            else:
+                hdu = shortname
+
         elif isinstance(fname, fits.hdu.hdulist.HDUList):
             shortname = fname
             extn = None
             extv = extver
 
+            if extver:
+                hdu = shortname[extver]
+            else:
+                hdu = shortname
+
         elif isinstance(fname, str):
             shortname, extn, extv = util.verify_filename(fname)
             if extn is not None:
@@ -606,31 +611,26 @@ class ginga_general(object):
             if extver is None:
                 extver = extv
 
+            # safety for a valid imexam file
+            if ((extv is None) and (extver is None)):
+                mef_file, nextend, first_image = util.check_valid(shortname)
+                extver = first_image  # the extension of the first IMAGE
+
+
         else:
             raise TypeError("Expected FITS data as input")
 
-        # safety for a valid imexam file
-        if ((extv is None) and (extver is None)):
-            mef_file, nextend, first_image = util.check_valid(shortname)
-            extver = first_image  # the extension of the first IMAGE
-
-        image = AstroImage(logger=self.logger)
-
         try:
-            if isinstance(fname, str):
+            if isinstance(shortname, str):
                 with fits.open(shortname) as filedata:
                     hdu = filedata[extver]
                     image.load_hdu(hdu)
             else:
-                if extver:
-                    hdu = shortname[extver]
-                else:
-                    hdu = shortname
                 image.load_hdu(hdu)
             self._set_frameinfo(fname=shortname, hdu=hdu, image=image)
             self.ginga_view.set_image(image)
         except Exception as e:
-            self.logger.error("Exception loading image: {0}".format(repr(e)))
+            self.logger.error(f"Exception loading image: {repr(e)}")
             raise Exception(repr(e))
 
     def panto_image(self, x, y):
@@ -690,7 +690,7 @@ class ginga_general(object):
             self.ginga_view.rotate(value)
 
         rot_deg = self.ginga_view.get_rotation()
-        print("Image rotated at {0:f} deg".format(rot_deg))
+        self.logger(f"Image rotated at {rot_deg} deg")
 
     def transform(self, flipx=None, flipy=None, swapxy=None):
         """Transform the frame.
@@ -805,7 +805,7 @@ class ginga_general(object):
             self.ginga_view.zoom_to(zoomlevel)
 
         except Exception as e:
-            print("problem with zoom: %s" % repr(e))
+            print(f"problem with zoom: {repr(e)}")
 
     def blink(self):
         """Blink multiple frames."""
@@ -937,7 +937,7 @@ class ginga(ginga_general):
             warnings.warn(
                 "webbrowser module not installed, see the installed \
                 doc directory for the HTML help pages")
-            print("Open a new browser window for: {}".format(self.ginga_view.url()))
+            print(f"Open a new browser window for: {self.ginga_view.url()}")
 
     def _create_viewer(self, bind_prefs, viewer_prefs,
                        opencv=False, threads=1):
