@@ -2,8 +2,6 @@
 
 Make sure that the basic plots in imexamine are working as expected.
 """
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose, assert_equal, assert_array_equal
@@ -18,6 +16,8 @@ except ImportError:
 try:
     import photutils
     HAS_PHOTUTILS = True
+    from packaging import version
+    photutils_version = version.parse(photutils.__version__)
 except ImportError:
     HAS_PHOTUTILS = False
 
@@ -57,7 +57,10 @@ def test_aper_phot(capsys):
     """Check that apertures are as expected from photutils"""
     radius = 5
     apertures = photutils.CircularAperture((50, 50), radius)
-    aperture_area = apertures.area()
+    if photutils_version >= version.parse('0.7'):
+        aperture_area = apertures.area
+    else:
+        aperture_area = apertures.area()
     assert_equal(aperture_area, np.pi * radius**2)
     rawflux_table = photutils.aperture_photometry(
         test_data,
@@ -222,13 +225,13 @@ def test_curve_of_growth():
     flux = []
 
     # Run the aperture phot on this to build up the expected fluxes
-    plots.aper_phot_pars['genplot'][0] = False
     plots.aper_phot_pars['subsky'][0] = False
+    plots.aper_phot_pars['center_com'][0] = False
 
     for rad in rads:
         plots.aper_phot_pars['radius'][0] = rad
-        plots.aper_phot(12, 12)
-        flux.append(plots.total_flux)
+        apertures, annulus_apertures, rawflux_table, sky_per_pix = plots.aper_phot(12, 12, genplot=False)
+        flux.append(rawflux_table['aperture_sum'][0])
 
     assert_array_equal(rads, rad_out)
     assert_allclose(flux, flux_out, 1e-6)
