@@ -1,7 +1,6 @@
 """Licensed under a 3-clause BSD style license - see LICENSE.rst."""
 
-from __future__ import print_function, division, absolute_import
-from xpa import xpa
+from .imexamxpa import xpa
 
 
 class XPA(xpa):
